@@ -6,7 +6,7 @@
 ## This code is free software; you can redistribute it and/or modify
 ## it under the same terms as Perl itself.
 ##
-## $Id: Core.pm,v 1.71 2003/05/13 22:49:13 vipul Exp $
+## $Id: Core.pm,v 1.72 2003/08/05 18:07:53 vipul Exp $
 
 package Razor2::Client::Core;
 
@@ -30,7 +30,7 @@ package Razor2::Client::Core;
                           fisher_yates_shuffle);
 
 
-($VERSION) = do { my @r = (q$Revision: 1.71 $ =~ /\d+/g); sprintf "%d."."%02d" x $#r, @r };
+($VERSION) = do { my @r = (q$Revision: 1.72 $ =~ /\d+/g); sprintf "%d."."%02d" x $#r, @r };
 $PROTOCOL = $Razor2::Client::Version::PROTOCOL; 
 
 
@@ -602,6 +602,10 @@ sub compute_sigs {
                 $self->log(6,"preproc: mail $objp->{id} went from $olen bytes to 0, erasing");
                 $objp->{skipme} = 1;
                 next;
+	    } elsif (($clen < 128)and($clnpart =~ /^(Content\S*:[^\n]*\n\r?)+(Content\S*:[^\n]*)?\s*$/s)) {
+                $self->log(6,"preproc: mail $objp->{id} seems empty, erasing");
+		$objp->{skipme} = 1;
+		next;
             } elsif ($clnpart !~ /\S/) {
                 $self->log(6,"preproc: mail $objp->{id} went to all whitespace, erasing");
                 $objp->{skipme} = 1;
